@@ -264,18 +264,6 @@ int Alsa_driver::pcm_start (void)
 {
     int   err, i, j, n;
 
-    if (_play_handle && ((err = snd_pcm_prepare (_play_handle)) < 0))
-    {
-	fprintf (stderr, "Alsa_driver: pcm_prepare(play): %s\n", snd_strerror (err));
-        return -1;
-    }
-
-    if (_capt_handle && !_synced && ((err = snd_pcm_prepare (_capt_handle)) < 0))
-    {
-	fprintf (stderr, "Alsa_driver: pcm_prepare(capt): %s\n", snd_strerror (err));
-        return -1;
-    }
-
     if (_play_handle)
     {
 	n = snd_pcm_avail_update (_play_handle);
@@ -685,7 +673,21 @@ int Alsa_driver::recover (void)
 		 1e3 * tnow.tv_sec - 1e3 * trig.tv_sec + 1e-3 * tnow.tv_usec - 1e-3 * trig.tv_usec);
     }
 
-    if (pcm_stop () || pcm_start ()) return -1;
+    if (pcm_stop ()) return -1;
+
+    if (_play_handle && ((err = snd_pcm_prepare (_play_handle)) < 0))
+    {
+	fprintf (stderr, "Alsa_driver: pcm_prepare(play): %s\n", snd_strerror (err));
+        return -1;
+    }
+
+    if (_capt_handle && !_synced && ((err = snd_pcm_prepare (_capt_handle)) < 0))
+    {
+	fprintf (stderr, "Alsa_driver: pcm_prepare(capt): %s\n", snd_strerror (err));
+        return -1;
+    }
+
+    if (pcm_start ()) return -1;
 
     return 0;
 }	
